@@ -79,6 +79,15 @@ NULL;
 NULL = NULL;
 NULL;
 
+NULL <=> NULL;
+TRUE;
+
+a IS NOT DISTINCT FROM a;
+TRUE;
+
+NULL IS DISTINCT FROM NULL;
+FALSE;
+
 NOT (NOT TRUE);
 TRUE;
 
